#
# spec file for package XyGrib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2018-2024 Dr. Axel Braun <DocB@opensuse.org>
# Copyright (c) 2018 Dominig ar Foll (Intel Open Source)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           XyGrib
Version:        1.2.6.1
Release:        8.4
Summary:        A weather visualization package
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://opengribs.org/en/
Source0:        https://github.com/opengribs/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}.desktop
Patch0:         QPainter.patch
Patch1:         libjpeg24.diff
Patch3:         projection.diff
Patch4:         proj9.diff
BuildRequires:  cmake
BuildRequires:  libnova-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} < 1500
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif

%description
XyGrib is a weather visualization package that interacts with
OpenGribs's Grib server providing a choice of global and large area
atmospheric and wave models.

XyGrib also uses pre-cut Gribs of high-resolution regional models
found on OpenSkiron.org.

%prep
%autosetup -p1

cp %{S:1} %{S:2} .

%build
# -DNO_UPDATE=1 deactivates XyGrib internal SW update
# -DOPENSUSE=1  macro for optional openSUSE friendly options in the source code
%cmake \
    -DCMAKE_INSTALL_PREFIX=%{_datadir}/openGribs \
	-DCMAKE_CXX_FLAGS="%{optflags} -DNO_UPDATE=1 -DOPENSUSE=1"
%cmake_build

%install
%cmake_install

# xygrib Makefile install is not very Linux
mkdir %{buildroot}/%{_bindir}
mv %{buildroot}/%{_datadir}/openGribs/XyGrib/XyGrib %{buildroot}/%{_bindir}/XyGrib

# Uses handmade xygrib.desktop file from OSB
%suse_update_desktop_file -i %{name}

# Starting with openSUSE 15.0 this is automatic
%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%doc README.md
%license LICENSE
%dir %attr(0755, root, root) %{_datadir}/openGribs
%{_bindir}/%{name}
%{_datadir}/openGribs/%{name}
%{_datadir}/applications/XyGrib.desktop
%{_datadir}/pixmaps/XyGrib.png

%changelog
* Mon Feb  5 2024 Axel Braun <axel.braun@gmx.de>
- proj8.diff removed (Leap 15.4 is deprecated)
  switch to %%autosetup for rpm 4.19 compatibility
* Thu Nov 24 2022 Axel Braun <axel.braun@gmx.de>
- proj version 9 breaks TW build
  proj9.diff added
* Tue Jun  7 2022 Axel Braun <axel.braun@gmx.de>
- adapted libjpeg24.diff to cope with openjpeg 2.5
* Thu Nov 18 2021 Axel Braun <axel.braun@gmx.de>
- proj8.diff and projection.diff added to fix build failure with proj 8
* Tue Mar  2 2021 Axel Braun <axel.braun@gmx.de>
- libjpeg24.diff added to fix build error with openjpeg 2.4
* Fri Jan 15 2021 Simon Lees <sflees@suse.de>
- Use %%cmake_build rather then %%make_jobs
* Sat Jul  4 2020 Axel Braun <axel.braun@gmx.de>
- QPainter.patch applied for build error in TW (gcc10)
  github.com/opengribs/XyGrib/pull/255
* Fri Jul 19 2019 Axel Braun <axel.braun@gmx.de>
- version 1.2.6.1
  Installation path fixed
* Tue Jul 16 2019 Axel Braun <axel.braun@gmx.de>
- Categories fixed
* Sun Jul 14 2019 Axel Braun <axel.braun@gmx.de>
- Version 1.2.6
- Macbook touchpad zooming of map issue fixed
- Belgium NMC opendata gribs can now be read by XyGrib
- GFS reflectivity added
- ECMWF ERA5 reanalysis data can now be read
- NOADD GFS Ensemble model can now be read
- Improvements in wave display
- utf-8 characters in file paths should be readable
- new icon
- Many behind the scenes improvements and bug fixes
* Thu Feb 21 2019 Jan Engelhardt <jengelh@inai.de>
- Remove marketing from descriptions.
* Thu Feb 21 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 1.2.4
- New feature - Arome 0.025 deg regional model added
- Grib grid only shown if there is weather display selected and z
  zoom factor allows it (no more black out)
- Many code improvements thanks to Didier
- Bug fixes including crashes on closing POI Editor or opening MeteoTable
* Wed Jan  9 2019 Axel Braun <axel.braun@gmx.de>
- version 1.2.2
- New feature - Gust color map
- Cloud display problems with ICON gribs is fixed.
- Enforcement of minimum area for grib requests is fixed.
- “Bad Request” errors are no longer returned on very small area requests.
- Several other bugs were fixed and several code stability improvements were included.
* Wed Dec 19 2018 Martin Pluskal <mpluskal@suse.com>
- Merge packaging changes from Dominig ar Foll
- Update to version 1.2.0
* Wed Jul 25 2018 mpluskal@suse.com
- Update to version 1.1.0
- Update build system and dependencies
* Wed May 30 2018 axel.braun@gmx.de
- Version 1.0.1
  Initial build on OBS
  Copyright added to spec file
  Changes originated in zyGrib:
* Thu Mar  8 2018 mpluskal@suse.com
- Use gcc7 for Leap
- Clean up spec file using spec-cleaner
* Sun Feb 12 2017 mpluskal@suse.com
- Cleanup spec file:
  * Use spec-cleaner
  * Drop codelite builddependency which prevented buildning on SLE
  * Force optflags on all targets
* Fri Dec  9 2016 axel.braun@gmx.de
- Version 8.0.1
  * Bug fixed: inverted sea current arrows
  * There was a problem with some dll in the Windows archive of the previous version.
  * Read GRIB 2 files.
  * Bug fixed: inverted sea current arrows.
  * Display equivalent potential temperature théta-e at the surface and in altitude (calculated from the temperature, pressure and moisture if it is not present in the file).
  * Faster calculation of the level lines.
  * Ability to interrupt before the opening of a large file.
  * Use QT version 5.
  * Use g2clib NOAA's g2clib library for decoding the GRIB2 format.
* Tue Nov 11 2014 axel.braun@gmx.de
- Version 6.2.4
- Source patch for qmake
* Sun Dec  1 2013 axel.braun@gmx.de
- New version 6.2.1
  x-------------------------------------------------------------------
* Sat Nov 16 2013 axel.braun@gmx.de
- Version 6.2.0, dependency on qwt removed
* Wed Oct 30 2013 axel.braun@gmx.de
- Version 6.1.4
* Tue Apr 23 2013 axel.braun@gmx.de
- version 6.1.3
* Thu Aug 16 2012 axel.braun@gmx.de
- release 6.0.0
- changes to spec file for Fedora/RHEL build
* Wed Dec 21 2011 idonmez@suse.com
- Fix license
* Wed Dec 21 2011 axel.braun@gmx.de
- release 5.1.0
* Thu Sep 22 2011 axel.braun@gmx.de
- release 5.0.6
* Sun Aug 14 2011 axel.braun@gmx.de
- Initial build.
  Thu Apr 01 2010
- Original Spec Build by "Brian K. White" <brian@aljex.com>
